@@ -23,15 +23,19 @@ def get_predictions(images, device=None, batch_size=50, print_every=20):
     Returns:
         ndarray: Batch of probabilities of equal size as number of images input.
     """
-    if device and device.index is not None:
-        # Avoid unbounded memory usage
-        gpu_options = tf.GPUOptions(allow_growth=True,
-                                    per_process_gpu_memory_fraction=0.15,
-                                    visible_device_list=str(device.index))
-        config = tf.ConfigProto(gpu_options=gpu_options)
+    # if device and device.index is not None:
+    #     # Avoid unbounded memory usage
+    #     gpu_options = tf.compat.v1.GPUOptions(allow_growth=True,
+    #                                 per_process_gpu_memory_fraction=0.15,
+    #                                 visible_device_list=str(device.index))
+    #     config = tf.compat.v1.ConfigProto(gpu_options=gpu_options)
 
-    else:
-        config = tf.ConfigProto(device_count={'GPU': 0})
+    # else:
+    #     config = tf.compat.v1.ConfigProto(device_count={'GPU': 0})
+
+    config = tf.compat.v1.ConfigProto()
+    config.gpu_options.per_process_gpu_memory_fraction = 0.2
+    config.gpu_options.allow_growth = True
 
     # Inference variables
     batch_size = min(batch_size, images.shape[0])
@@ -39,14 +43,16 @@ def get_predictions(images, device=None, batch_size=50, print_every=20):
 
     # Get predictions
     preds = []
-    with tf.Session(config=config) as sess:
+    with tf.compat.v1.Session(config=config) as sess:
         # Batch input preparation
         inception_utils._get_inception_layer(sess)
 
         # Define input/outputs of default graph.
-        pool3 = sess.graph.get_tensor_by_name('inception_model/pool_3:0')
-        w = sess.graph.get_operation_by_name(
-            "inception_model/softmax/logits/MatMul").inputs[1]
+        pool3 = sess.graph.get_tensor_by_name('pool_3:0')
+        w = sess.graph.get_operation_by_name("softmax/logits/MatMul").inputs[1]
+        # pool3 = sess.graph.get_tensor_by_name('inception_model/pool_3:0') # TODO: Remove when safe. TF2 syntax changes again.
+        # w = sess.graph.get_operation_by_name(
+        #     "inception_model/softmax/logits/MatMul").inputs[1] # TODO: Remove when safe. TF2 syntax changes again.
         logits = tf.matmul(tf.squeeze(pool3, [1, 2]), w)
         softmax = tf.nn.softmax(logits)
 
@@ -55,8 +61,8 @@ def get_predictions(images, device=None, batch_size=50, print_every=20):
         for i in range(num_batches):
             batch = images[i * batch_size:(i + 1) * batch_size]
 
-            # curr_image = np.expand_dims(images[i], axis=0)
-            pred = sess.run(softmax, {'inception_model/ExpandDims:0': batch})
+            pred = sess.run(softmax, {'ExpandDims:0': batch})
+            # pred = sess.run(softmax, {'inception_model/ExpandDims:0': batch}) # TODO: Remove when safe. TF2 syntax changes again.
             preds.append(pred)
 
             if (i + 1) % min(print_every, num_batches) == 0:
