@@ -1,2 +1,2 @@
 from . import (basemodel, gan, dcgan, wgan_gp, sngan, cgan_pd, ssgan,
-               infomax_gan)
+               infomax_gan, sagan)
