@@ -19,7 +19,7 @@ class LRScheduler:
         lr_D (float): The initial learning rate of optD.
         lr_G (float): The initial learning rate of optG.
     """
-    def __init__(self, lr_decay, optD, optG, num_steps, **kwargs):
+    def __init__(self, lr_decay, optD, optG, num_steps, start_step=0, **kwargs):
         if lr_decay not in [None, 'None', 'linear']:
             raise NotImplementedError(
                 "lr_decay {} is not currently supported.")
@@ -28,6 +28,7 @@ class LRScheduler:
         self.optD = optD
         self.optG = optG
         self.num_steps = num_steps
+        self.start_step = start_step
 
         # Cache the initial learning rate for uses later
         self.lr_D = optD.param_groups[0]['lr']
@@ -89,21 +90,17 @@ class LRScheduler:
             lr_D = self.linear_decay(optimizer=self.optD,
                                      global_step=global_step,
                                      lr_value_range=(self.lr_D, 0.0),
-                                     lr_step_range=(0, self.num_steps))
+                                     lr_step_range=(self.start_step, self.num_steps))
 
             lr_G = self.linear_decay(optimizer=self.optG,
                                      global_step=global_step,
                                      lr_value_range=(self.lr_G, 0.0),
-                                     lr_step_range=(0, self.num_steps))
+                                     lr_step_range=(self.start_step, self.num_steps))
 
         elif self.lr_decay in [None, "None"]:
             lr_D = self.lr_D
             lr_G = self.lr_G
 
-        else:
-            raise ValueError("Invalid lr_decay method {} selected.".format(
-                self.lr_decay))
-
         # Update metrics log
         log_data.add_metric('lr_D', lr_D, group='lr', precision=6)
         log_data.add_metric('lr_G', lr_G, group='lr', precision=6)
